package javax.security.cert;

import java.security.SignatureException;
import java.security.NoSuchProviderException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.PublicKey;

public abstract class Certificate
{
    public Certificate() {
    }
    
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof Certificate)) {
            return false;
        }
        try {
            byte[] encoded = this.getEncoded();
            byte[] encoded2 = ((Certificate)o).getEncoded();
            if (encoded.length != encoded2.length) {
                return false;
            }
            int i = 0;
            while (i < encoded.length) {
                if (encoded[i] != encoded2[i]) {
                    return false;
                }
                ++i;
            }
            return true;
        }
        catch (CertificateException ex) {
            return false;
        }
    }
    
    @Override
    public int hashCode() {
        int n = 0;
        try {
            byte[] encoded = this.getEncoded();
            for (int i = 1; i < encoded.length; ++i) {
                n += encoded[i] * i;
            }
            return n;
        }
        catch (CertificateException ex) {
            return n;
        }
    }
    
    public abstract byte[] getEncoded() throws CertificateEncodingException;
    
    public abstract void verify(PublicKey p0) throws CertificateException, NoSuchAlgorithmException, InvalidKeyException, NoSuchProviderException, SignatureException;
    
    public abstract void verify(PublicKey p0, String p1) throws CertificateException, NoSuchAlgorithmException, InvalidKeyException, NoSuchProviderException, SignatureException;
    
    @Override
    public abstract String toString();
    
    public abstract PublicKey getPublicKey();
}
